@@ -37,4 +37,11 @@
 #include <netdb/services.h>
 #include <netdb/rpc.h>
 
+#if defined(_POSIX_THREAD_SAFE_FUNCTIONS) || defined(_REENTRANT)
+int *__h_errno_location __P((void));
+#define h_errno	(*__h_errno_location ())
+#else
+extern int h_errno;
+#endif
+
 #endif
